@@ -41,6 +41,8 @@
 
 #define SONNETUI_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))
 
+#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))
+
 /* Take any defaults from group settings */
 #if !defined(SONNETUI_NO_DEPRECATED) && !defined(SONNETUI_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #  ifdef KF_NO_DEPRECATED
@@ -84,7 +86,7 @@
 #define SONNETUI_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef SONNETUI_NO_DEPRECATED
-#  define SONNETUI_DISABLE_DEPRECATED_BEFORE_AND_AT 0x57400
+#  define SONNETUI_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54500
 #endif
 #ifdef SONNETUI_NO_DEPRECATED_WARNINGS
 #  define SONNETUI_DEPRECATED_WARNINGS_SINCE 0
@@ -94,7 +96,7 @@
 #  ifdef SONNETUI_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define SONNETUI_DEPRECATED_WARNINGS_SINCE SONNETUI_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define SONNETUI_DEPRECATED_WARNINGS_SINCE 0x57400
+#    define SONNETUI_DEPRECATED_WARNINGS_SINCE 0x54500
 #  endif
 #endif
 
@@ -103,7 +105,7 @@
 #endif
 
 #ifdef SONNETUI_DEPRECATED
-#  define SONNETUI_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > SONNETUI_DISABLE_DEPRECATED_BEFORE_AND_AT)
+#  define SONNETUI_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > SONNETUI_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #else
 #  define SONNETUI_ENABLE_DEPRECATED_SINCE(major, minor) 0
 #endif
@@ -115,13 +117,5 @@
 #endif
 #define SONNETUI_DEPRECATED_VERSION_5(minor, text)      SONNETUI_DEPRECATED_VERSION_5_##minor(text)
 #define SONNETUI_DEPRECATED_VERSION(major, minor, text) SONNETUI_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
-#define SONNETUI_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) SONNETUI_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
-#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
-#  define SONNETUI_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) SONNETUI_DEPRECATED_VERSION(major, minor, text)
-#  define SONNETUI_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) SONNETUI_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
-#else
-#  define SONNETUI_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
-#  define SONNETUI_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
-#endif
 
 #endif /* SONNETUI_EXPORT_H */
